PlayDataSafetyRow class

A merged row for one distinct data type across all matched SDKs.

Constructors

PlayDataSafetyRow({required String dataType, required bool sharedWithThirdParties, required Set<String> purposes, required bool optional, required bool encryptedInTransit, required bool userCanRequestDeletion, required List<String> collectedBySdks})
const

Properties

collectedBySdks List<String>
final
dataType String
final
encryptedInTransit bool
final
hashCode int
The hash code for this object.
no setterinherited
optional bool
final
purposes Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedWithThirdParties bool
final
userCanRequestDeletion bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited