PolicySummaryGenerator class

Generates a plain-English privacy-policy paragraph from matched SDKs.

Constructors

PolicySummaryGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(List<SdkEntry> sdks, {ProjectInfo? project}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeToFile(List<SdkEntry> sdks, String outputPath, {ProjectInfo? project}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited