DependencyResolver class

Constructors

DependencyResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

directOnly(List<ScannedDependency> deps) List<ScannedDependency>
Direct dependencies only.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packageNames(List<ScannedDependency> deps) List<String>
Returns package names only, sorted alphabetically.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited