ProjectInfo class

Project identity fields from pubspec.yaml (not Apple plist keys).

Constructors

ProjectInfo({required String name, required String version, required String projectPath, String? description})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
projectPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited