ScannedDependency class

A single dependency discovered from pubspec.yaml / pubspec.lock.

Constructors

ScannedDependency({required String packageName, required String resolvedVersion, required bool isDirect})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isDirect bool
final
packageName String
final
resolvedVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override