SdkEntry class
An SDK database entry describing a known Flutter package's data practices.
Constructors
-
SdkEntry({required String package, required String displayName, required List<
DataCollectionItem> dataCollected, required bool encryptedInTransit, required bool userCanRequestDeletion, required bool requiresXcprivacyEntry, required List<String> requiredReasonApis, String? notes}) -
const
- SdkEntry.fromYaml(YamlMap map)
-
factory
Properties
-
dataCollected
→ List<
DataCollectionItem> -
final
- displayName → String
-
final
- encryptedInTransit → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notes → String?
-
final
- package → String
-
final
-
requiredReasonApis
→ List<
String> -
final
- requiresXcprivacyEntry → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userCanRequestDeletion → bool
-
final
Methods
-
merge(
SdkEntry override) → SdkEntry - Returns a copy with any non-null override fields applied.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited